GradientTrackShape class

Inheritance

Constructors

GradientTrackShape({required LinearGradient gradient, double trackHeight = 4.0})

Properties

gradient LinearGradient
final
hashCode int
The hash code for this object.
no setterinherited
isRounded bool
Whether the track shape is rounded.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackHeight double
final

Methods

getPreferredRect({required RenderBox parentBox, Offset offset = Offset.zero, required SliderThemeData sliderTheme, bool isEnabled = false, bool isDiscrete = false}) Rect
Returns the preferred bounds of the shape.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset, {required Animation<double> enableAnimation, required RenderBox parentBox, Offset? secondaryOffset, required SliderThemeData sliderTheme, required TextDirection textDirection, required Offset thumbCenter, bool isEnabled = false, bool isDiscrete = false}) → void
Paints the track shape based on the state passed to it.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited